@@ -16,14 +16,6 @@
  */
 package org.apache.camel.upgrade;
 
-import java.nio.file.Path;
-import java.nio.file.Paths;
-import java.util.Arrays;
-import java.util.Comparator;
-import java.util.List;
-import java.util.Objects;
-import java.util.Optional;
-
 import org.openrewrite.InMemoryExecutionContext;
 import org.openrewrite.Parser;
 import org.openrewrite.java.JavaParser;
@@ -31,6 +23,10 @@ import org.openrewrite.test.RecipeSpec;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.nio.file.Path;
+import java.nio.file.Paths;
+import java.util.*;
+
 public class CamelTestUtil {
     private static final Logger LOGGER = LoggerFactory.getLogger(CamelTestUtil.class);
 
@@ -48,7 +44,8 @@ public class CamelTestUtil {
         v4_9(4, 9, 0),
         v4_10(4, 10, 0),
         v4_11(4, 11, 0),
-        v4_12(4, 12, 0);
+        v4_12(4, 12, 0),
+        v4_13(4, 13, 0);
 
         private int major;
         private int minor;
@@ -77,10 +74,6 @@ public class CamelTestUtil {
         }
     }
 
-    private static RecipeSpec recipe(RecipeSpec spec, CamelVersion to) {
-        return recipe(spec, to, to.getRecipe());
-    }
-
     public static RecipeSpec recipe(RecipeSpec spec, CamelVersion to, String... activeRecipes) {
         if (activeRecipes == null || activeRecipes.length == 0) {
             return spec.recipeFromResource(to.getYamlFile(), to.getRecipe());
@@ -90,32 +83,32 @@ public class CamelTestUtil {
 
     public static Parser.Builder parserFromClasspath(CamelVersion from, String... classpath) {
         List<String> resources = Arrays.stream(classpath).map(cl -> {
-                    if (cl.startsWith("camel-")) {
-                        String maxVersion = cl + "-" + from.getVersion();
-                        //find the highest version lesser or equals the required one
-                        Path path = Paths.get("target", "test-classes", "META-INF", "rewrite", "classpath");
-                        Optional<String> dependency = Arrays.stream(path.toFile().listFiles())
-                                .filter(f -> f.getName().startsWith(cl))
-                                .map(f -> f.getName().substring(0, f.getName().lastIndexOf(".")))
-                                //filter out or higher version the requested
-                                .filter(f -> f.compareTo(maxVersion) <= 0)
-                                .sorted(Comparator.reverseOrder())
-                                .findFirst();
+              if (cl.startsWith("camel-")) {
+                  String maxVersion = cl + "-" + from.getVersion();
+                  //find the highest version lesser or equals the required one
+                  Path path = Paths.get("target", "test-classes", "META-INF", "rewrite", "classpath");
+                  Optional<String> dependency = Arrays.stream(path.toFile().listFiles())
+                    .filter(f -> f.getName().startsWith(cl))
+                    .map(f -> f.getName().substring(0, f.getName().lastIndexOf(".")))
+                    //filter out or higher version the requested
+                    .filter(f -> f.compareTo(maxVersion) <= 0)
+                    .sorted(Comparator.reverseOrder())
+                    .findFirst();
 
-                        if (dependency.isEmpty()) {
-                            LOGGER.warn("Dependency not found in classpath: {}", cl);
-                        }
+                  if (dependency.isEmpty()) {
+                      LOGGER.warn("Dependency not found in classpath: {}", cl);
+                  }
 
-                        return dependency.orElse(null);
-                    }
-                    return cl;
-                })
-                .filter(Objects::nonNull)
-                .toList();
+                  return dependency.orElse(null);
+              }
+              return cl;
+          })
+          .filter(Objects::nonNull)
+          .toList();
 
         return JavaParser.fromJavaVersion()
-                .logCompilationWarningsAndErrors(true)
-                .classpathFromResources(new InMemoryExecutionContext(), resources.toArray(new String[0]));
+          .logCompilationWarningsAndErrors(true)
+          .classpathFromResources(new InMemoryExecutionContext(), resources.toArray(new String[0]));
     }
 
 }
